@@ -6,6 +6,7 @@ use strict;
 use warnings;
 
 use File::Slurper qw(read_binary);
+use File::Temp qw(tempfile);
 use MIDI::Simple ();
 use Music::Tempo qw(bpm_to_ms);
 use Moo;
@@ -29,15 +30,23 @@ our @EXPORT = qw(
     x
 );
 
-our $VERSION = '0.0202';
+our $VERSION = '0.0300';
 
 my $self;
 
 sub BEGIN {
     has filename => (
         is      => 'rw',
-        default => sub { 'idi.mid' },
+        builder => 1,
     );
+    sub _build_filename {
+        my ($fh, $filename) = tempfile('idi-XXXX',
+            DIR    => '.',
+            SUFFIX => '.mid',
+            UNLINK => 1,
+        );
+        return $filename;
+    }
 
     has score => (
         is      => 'ro',
@@ -224,13 +233,29 @@ No-op (with C<MIDI::Simple::noop>)
 =for Pod::Coverage play
 =for Pod::Coverage is_written
 
+=head1 SEE ALSO
+
+L<File::Slurper>
+
+L<File::Temp>
+
+L<MIDI::Simple>
+
+L<Music::Tempo>
+
+L<Moo>
+
+L<strictures>
+
+L<namespace::clean>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2021 by Gene Boggs.
+This software is Copyright (c) 2022 by Gene Boggs.
 
 This is free software, licensed under: The Artistic License 2.0 (GPL Compatible)
 
